@@ -317,9 +317,8 @@ const MainView = new Lang.Class({
                   
         this.groupGrid.add(this._scrolledWin);
         this._scrolledWin.show();
-        let itemNumber = list.getItemCount();
-        let title;
-        
+        let sounds = list.getItemCount();
+        let title
         // Translators: This is the title in the headerbar
         if (sounds > 0) {
             title = Gettext.ngettext("%d Recorded Sound",
